"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const puppeteer = require("puppeteer");
const browser_1 = require("./browser");
class ReusableBrowser extends browser_1.Browser {
    constructor(config, log) {
        super(config, log);
    }
    start() {
        return __awaiter(this, void 0, void 0, function* () {
            const launcherOptions = this.getLauncherOptions({});
            this.browser = yield puppeteer.launch(launcherOptions);
        });
    }
    render(options) {
        return __awaiter(this, void 0, void 0, function* () {
            let context;
            let page;
            try {
                this.validateOptions(options);
                context = yield this.browser.createIncognitoBrowserContext();
                page = yield context.newPage();
                if (options.timezone) {
                    // set timezone
                    yield page.emulateTimezone(options.timezone);
                }
                this.addPageListeners(page);
                return yield this.takeScreenshot(page, options);
            }
            finally {
                if (page) {
                    this.removePageListeners(page);
                    yield page.close();
                }
                if (context) {
                    yield context.close();
                }
            }
        });
    }
}
exports.ReusableBrowser = ReusableBrowser;
//# sourceMappingURL=reusable.js.map