"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const grpc = require("@grpc/grpc-js");
const protoLoader = require("@grpc/proto-loader");
const browser_1 = require("../../browser");
const renderPackageDef = protoLoader.loadSync(__dirname + '/../../../proto/renderer.proto', {
    keepCase: true,
    longs: String,
    enums: String,
    defaults: true,
    oneofs: true,
});
const rendererProtoDescriptor = grpc.loadPackageDefinition(renderPackageDef);
class RenderGRPCPluginV1 {
    constructor(config, log) {
        this.config = config;
        this.log = log;
    }
    grpcServer(server) {
        return __awaiter(this, void 0, void 0, function* () {
            const serviceDef = rendererProtoDescriptor['models']['Renderer']['service'];
            const browser = browser_1.createBrowser(this.config.rendering, this.log);
            server.addService(serviceDef, {
                render: (call, callback) => {
                    const req = call.request;
                    const options = {
                        url: req.url,
                        width: req.width,
                        height: req.height,
                        filePath: req.filePath,
                        timeout: req.timeout,
                        renderKey: req.renderKey,
                        domain: req.domain,
                        timezone: req.timezone,
                        encoding: req.encoding,
                    };
                    this.log.debug('Render request received', 'url', options.url);
                    browser.render(options).then(() => {
                        callback(null, { error: '' });
                    }, err => {
                        this.log.error('Render request failed', 'url', options.url, 'error', err.toString());
                        callback(null, { error: err.toString() });
                    });
                },
            });
            yield browser.start();
        });
    }
}
exports.RenderGRPCPluginV1 = RenderGRPCPluginV1;
//# sourceMappingURL=grpc_plugin.js.map