"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const promBundle = require("express-prom-bundle");
exports.metricsMiddleware = (config, log) => {
    if (!config.enabled) {
        return (req, res, next) => {
            next();
        };
    }
    log.info('Metrics enabled', 'collectDefaultMetrics', config.collectDefaultMetrics, 'requestDurationBuckets', config.requestDurationBuckets.join(','));
    const opts = {
        httpDurationMetricName: 'grafana_image_renderer_service_http_request_duration_seconds',
        metricType: 'histogram',
        buckets: config.requestDurationBuckets,
        excludeRoutes: [/^((?!(render)).)*$/],
        promClient: {},
        formatStatusCode: res => {
            if (res && res.req && res.req.aborted) {
                // Nginx non-standard code 499 Client Closed Request
                // Used when the client has closed the request before
                // the server could send a response.
                return 499;
            }
            return res.status_code || res.statusCode;
        },
    };
    if (config.collectDefaultMetrics) {
        opts.promClient.collectDefaultMetrics = {};
    }
    const bundle = promBundle(opts);
    return bundle;
};
//# sourceMappingURL=metrics_middleware.js.map